==> jc-1.4.0.tar.gz: javax/crypto/spec/DHParameterSpec.h <==
// public class javax.crypto.spec.DHParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 715895435e647a9e javax_crypto_spec_DHParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHParameterSpec_H_
#define _JC_javax_crypto_spec_DHParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHParameterSpec$sub_refs	_jc_javax_crypto_spec_DHParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$refs	_jc_javax_crypto_spec_DHParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$nonrefs	_jc_javax_crypto_spec_DHParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$object	_jc_javax_crypto_spec_DHParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_DHParameterSpec$vmethods	_jc_javax_crypto_spec_DHParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHParameterSpec$vtable	_jc_javax_crypto_spec_DHParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHParameterSpec$vtype	_jc_javax_crypto_spec_DHParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHParameterSpec$method$_init$112bcad7f4f53827(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *);
extern void _jc_javax_crypto_spec_DHParameterSpec$method$_init$75111dc98c281e8a(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, jint);

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHParameterSpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *);
extern jint _jc_javax_crypto_spec_DHParameterSpec$method$getL$f03455be7d7e4d5a(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *);
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHParameterSpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHParameterSpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_javax_crypto_spec_DHParameterSpec$method_info$getL$f03455be7d7e4d5a;
extern _jc_method _jc_javax_crypto_spec_DHParameterSpec$method_info$getP$612c6062f1779963;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHParameterSpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *);
	jint	(*getL$f03455be7d7e4d5a)(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *);
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_DHParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHParameterSpec$vmethods	javax_crypto_spec_DHParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHParameterSpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*g;
	struct _jc_java_math_BigInteger$object	*p;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHParameterSpec$refs {
    _jc_javax_crypto_spec_DHParameterSpec$sub_refs	javax_crypto_spec_DHParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs {
	jint	l;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs	javax_crypto_spec_DHParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHParameterSpec$object {
	_jc_javax_crypto_spec_DHParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHParameterSpec$vtype _jc_javax_crypto_spec_DHParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHParameterSpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/DHParameterSpec.h <==
// public class javax.crypto.spec.DHParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 715895435e647a9e javax_crypto_spec_DHParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_DHParameterSpec_H_
#define _JC_javax_crypto_spec_DHParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_math_BigInteger$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_DHParameterSpec$sub_refs	_jc_javax_crypto_spec_DHParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$refs	_jc_javax_crypto_spec_DHParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$nonrefs	_jc_javax_crypto_spec_DHParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_DHParameterSpec$object	_jc_javax_crypto_spec_DHParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_DHParameterSpec$vmethods	_jc_javax_crypto_spec_DHParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_DHParameterSpec$vtable	_jc_javax_crypto_spec_DHParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_DHParameterSpec$vtype	_jc_javax_crypto_spec_DHParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_DHParameterSpec$method$_init$112bcad7f4f53827(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_DHParameterSpec$method$_init$75111dc98c281e8a(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *, struct _jc_java_math_BigInteger$object *, struct _jc_java_math_BigInteger$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHParameterSpec$method$getG$59cffd735b56d8ad(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_DHParameterSpec$method$getL$f03455be7d7e4d5a(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *) _JC_JCNI_ATTR;
extern struct _jc_java_math_BigInteger$object *_jc_javax_crypto_spec_DHParameterSpec$method$getP$612c6062f1779963(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_DHParameterSpec$method_info$getG$59cffd735b56d8ad;
extern _jc_method _jc_javax_crypto_spec_DHParameterSpec$method_info$getL$f03455be7d7e4d5a;
extern _jc_method _jc_javax_crypto_spec_DHParameterSpec$method_info$getP$612c6062f1779963;

// Virtual methods structure
struct _jc_javax_crypto_spec_DHParameterSpec$vmethods {
	struct _jc_java_math_BigInteger$object	*(*getG$59cffd735b56d8ad)(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *) _JC_JCNI_ATTR;
	jint	(*getL$f03455be7d7e4d5a)(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *) _JC_JCNI_ATTR;
	struct _jc_java_math_BigInteger$object	*(*getP$612c6062f1779963)(_jc_env *, struct _jc_javax_crypto_spec_DHParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_DHParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_DHParameterSpec$vmethods	javax_crypto_spec_DHParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_DHParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_DHParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHParameterSpec$sub_refs {
	struct _jc_java_math_BigInteger$object	*g;
	struct _jc_java_math_BigInteger$object	*p;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_DHParameterSpec$refs {
    _jc_javax_crypto_spec_DHParameterSpec$sub_refs	javax_crypto_spec_DHParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs {
	jint	l;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_DHParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_DHParameterSpec$sub_nonrefs	javax_crypto_spec_DHParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_DHParameterSpec$object {
	_jc_javax_crypto_spec_DHParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_DHParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_DHParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_DHParameterSpec$vtype _jc_javax_crypto_spec_DHParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_DHParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_DHParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_DHParameterSpec_H_ */
